==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1CronJobSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Boolean;

public interface V1beta1CronJobSpecFluent<A extends V1beta1CronJobSpecFluent<A>> extends Fluent<A>{


    public String getConcurrencyPolicy();
    public A withConcurrencyPolicy(String concurrencyPolicy);
    public Boolean hasConcurrencyPolicy();
    public Integer getFailedJobsHistoryLimit();
    public A withFailedJobsHistoryLimit(Integer failedJobsHistoryLimit);
    public Boolean hasFailedJobsHistoryLimit();
    public A withNewFailedJobsHistoryLimit(int arg1);
    public A withNewFailedJobsHistoryLimit(String arg1);
    
/**
 * This method has been deprecated, please use method buildJobTemplate instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1JobTemplateSpec getJobTemplate();
    public V1beta1JobTemplateSpec buildJobTemplate();
    public A withJobTemplate(V1beta1JobTemplateSpec jobTemplate);
    public Boolean hasJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplateLike(V1beta1JobTemplateSpec item);
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> editJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplateLike(V1beta1JobTemplateSpec item);
    public String getSchedule();
    public A withSchedule(String schedule);
    public Boolean hasSchedule();
    public Long getStartingDeadlineSeconds();
    public A withStartingDeadlineSeconds(Long startingDeadlineSeconds);
    public Boolean hasStartingDeadlineSeconds();
    public A withNewStartingDeadlineSeconds(String arg1);
    public A withNewStartingDeadlineSeconds(long arg1);
    public Integer getSuccessfulJobsHistoryLimit();
    public A withSuccessfulJobsHistoryLimit(Integer successfulJobsHistoryLimit);
    public Boolean hasSuccessfulJobsHistoryLimit();
    public A withNewSuccessfulJobsHistoryLimit(int arg1);
    public A withNewSuccessfulJobsHistoryLimit(String arg1);
    public Boolean isSuspend();
    public A withSuspend(Boolean suspend);
    public Boolean hasSuspend();
    public A withNewSuspend(boolean arg1);
    public A withNewSuspend(String arg1);

    public interface JobTemplateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1JobTemplateSpecFluent<V1beta1CronJobSpecFluent.JobTemplateNested<N>>{

        
    public N and();    public N endJobTemplate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CronJobSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Boolean;

public interface V1beta1CronJobSpecFluent<A extends V1beta1CronJobSpecFluent<A>> extends Fluent<A>{


    public String getConcurrencyPolicy();
    public A withConcurrencyPolicy(String concurrencyPolicy);
    public Boolean hasConcurrencyPolicy();
    public A withNewConcurrencyPolicy(String arg1);
    public A withNewConcurrencyPolicy(StringBuilder arg1);
    public A withNewConcurrencyPolicy(StringBuffer arg1);
    public Integer getFailedJobsHistoryLimit();
    public A withFailedJobsHistoryLimit(Integer failedJobsHistoryLimit);
    public Boolean hasFailedJobsHistoryLimit();
    
/**
 * This method has been deprecated, please use method buildJobTemplate instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1JobTemplateSpec getJobTemplate();
    public V1beta1JobTemplateSpec buildJobTemplate();
    public A withJobTemplate(V1beta1JobTemplateSpec jobTemplate);
    public Boolean hasJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplateLike(V1beta1JobTemplateSpec item);
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> editJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplate();
    public V1beta1CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplateLike(V1beta1JobTemplateSpec item);
    public String getSchedule();
    public A withSchedule(String schedule);
    public Boolean hasSchedule();
    public A withNewSchedule(String arg1);
    public A withNewSchedule(StringBuilder arg1);
    public A withNewSchedule(StringBuffer arg1);
    public Long getStartingDeadlineSeconds();
    public A withStartingDeadlineSeconds(Long startingDeadlineSeconds);
    public Boolean hasStartingDeadlineSeconds();
    public Integer getSuccessfulJobsHistoryLimit();
    public A withSuccessfulJobsHistoryLimit(Integer successfulJobsHistoryLimit);
    public Boolean hasSuccessfulJobsHistoryLimit();
    public Boolean isSuspend();
    public A withSuspend(Boolean suspend);
    public Boolean hasSuspend();
    public A withNewSuspend(String arg1);
    public A withNewSuspend(boolean arg1);

    public interface JobTemplateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1JobTemplateSpecFluent<V1beta1CronJobSpecFluent.JobTemplateNested<N>>{

        
    public N and();    public N endJobTemplate();
}


}
